@@ -1,7 +1,7 @@
 // -*- c++ -*-
 #ifndef _LIBGDAMM_INIT_H
 #define _LIBGDAMM_INIT_H
-/* $Id: init.h,v 1.3 2002/11/02 17:44:08 murrayc Exp $ */
+/* $Id: init.h 1556 2008-06-10 11:11:02Z jhs $ */
 
 /* init.h
  *
@@ -22,6 +22,8 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <glibmm.h>
+
 
 namespace Gnome
 {
@@ -29,6 +31,8 @@ namespace Gnome
 namespace Gda
 {
 
+void init();
+
 } //namespace Gda
 } //namespace Gnome
 
